@@ -193,24 +193,20 @@ class ShippingMethod(object):
         (SELF_FLASH, "自费闪送"),
     )
 
-
-class ShippingMethodInt:
-    ''' 配送方式的 int 编码 '''
-
-    # 自提
-    SELF_SERVICE_INT = 1
-    # 快递
-    EXPRESS_INT = 2
-    # 自费闪送
-    SELF_FLASH_INT = 4
-    # 闪送
-    FLASH_DELIVERY_INT = 8
+    # # 自提
+    # SELF_SERVICE_INT = 1<<0
+    # # 快递
+    # EXPRESS_INT = 1<<1
+    # # 自费闪送
+    # SELF_FLASH_INT = 1<<2
+    # # 闪送
+    # FLASH_DELIVERY_INT = 1<<3
 
     str2int_map = {
-        ShippingMethod.EXPRESS: EXPRESS_INT,
-        ShippingMethod.SELF_SERVICE: SELF_SERVICE_INT,
-        ShippingMethod.SELF_FLASH: SELF_FLASH_INT,
-        ShippingMethod.FLASH_DELIVERY: FLASH_DELIVERY_INT
+        SELF_SERVICE: 1 << 0,
+        EXPRESS: 1 << 1,
+        SELF_FLASH: 1 << 2,
+        FLASH_DELIVERY: 1 << 3,
     }
 
     int2str_map = {v: k for k, v in str2int_map.items()}
