@@ -5,10 +5,11 @@ from django.utils.translation import ugettext_lazy as _
 
 from ..core.base_models import BaseModelTimeAndDeleted
 from ..core.common_utils import get_uuid4_hex
+from ..core.constants import ShippingMethod
 from ..core.numbers import getRandomNumSet
 from ..sparrow_orders.constants import PayMethod
 from ..sparrow_orders.constants import DeliverTimeType
-from .constants import DistributeStatus, ShippingMethod
+from .constants import DistributeStatus
 from . import APP_LABEL
 
 __all__ = ['Distribute', 'Distributeline', 'FootPrint', 'ExpressRela',
@@ -30,11 +31,6 @@ class Distribute(BaseModelTimeAndDeleted):
     '''
     配货单总表
     '''
-    SHIPPING_METHOD_CHOICES = (
-        (ShippingMethod.EXPRESS, '快递'),
-        (ShippingMethod.SELF_SERVICE, '自提'),
-        (ShippingMethod.FLASH_DELIVERY, '闪送'),
-    )
     # id(主键uuid)
     id = models.CharField(max_length=100, primary_key=True, default=get_uuid4_hex, editable=False)
     # 发货单名称（包裹1、包裹2等，这个名称并不是固定的，由于客户提货或者售后造成的拆单，可能造成这个字段值发生变化）
@@ -56,7 +52,7 @@ class Distribute(BaseModelTimeAndDeleted):
     # aftersale_status(有售后，无售后)
     aftersale_status = models.BooleanField("是否有售后", default=False, db_index=True)
     # shipping_method(发货方式：自提、快递、闪送)
-    shipping_method = models.CharField('发货方式', max_length=128, blank=True, null=True, choices=SHIPPING_METHOD_CHOICES, db_index=True)
+    shipping_method = models.CharField('发货方式', max_length=128, blank=True, null=True, choices=ShippingMethod.CHOICES, db_index=True)
     # print_times打印次数
     print_times = models.IntegerField(_("打印次数"), default=0)
     # shop_id(专柜id)
